# eric7.EricCore.EricPreferences

Module implementing the preferences for the eric library.

### Global Attributes

settingsNameGlobal
settingsNameOrganization

### Classes

EricPreferences | A class to hold all configuration items.

### Functions

convertPasswords | Module function to convert all passwords.
getNetworkProxy | Function to retrieve the various Network Proxy related settings.
initPreferences | Function to initialize the central configuration store.
setNetworkProxy | Function to store the various Network Proxy settings.
syncPreferences | Module function to sync the preferences to disk.

## EricPreferences

A class to hold all configuration items.

### Derived from

None

### Class Attributes

proxyDefaults

### Class Methods

None

### Methods

None

### Static Methods

None

Up

## convertPasswords

convertPasswords(oldPassword, newPassword)

Module function to convert all passwords.

oldPassword (str)
  current password
newPassword (str)
  new password

Up

## getNetworkProxy

getNetworkProxy(key)

Function to retrieve the various Network Proxy related settings.

key (str)
  the key of the value to get

Return:
  the requested network proxy setting

Return Type:
  Any

Up

## initPreferences

initPreferences()

Function to initialize the central configuration store.

Up

## setNetworkProxy

setNetworkProxy(key, value)

Function to store the various Network Proxy settings.

key (str)
  the key of the setting to be set
value (Any)
  the value to be set

Up

## syncPreferences

syncPreferences()

Module function to sync the preferences to disk.

In addition to syncing, the central configuration store is reinitialized as well.

Up